@@ -19,7 +19,7 @@
 
 
 from .inspector import InspectorShap
-from .shap_dependence import TreeDependencePlotter
+from .shap_dependence import DependencePlotter
 from .model_interpret import ShapModelInterpreter
 
-__all__ = ["InspectorShap", "TreeDependencePlotter", "ShapModelInterpreter"]
+__all__ = ["InspectorShap", "DependencePlotter", "ShapModelInterpreter"]
