@@ -18,5 +18,14 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-from .resemblance_model import BaseResemblanceModel, PermutationImportanceResemblance, SHAPImportanceResemblance
-__all__ = ['BaseResemblanceModel', 'PermutationImportanceResemblance', 'SHAPImportanceResemblance']
+from .resemblance_model import (
+    BaseResemblanceModel,
+    PermutationImportanceResemblance,
+    SHAPImportanceResemblance,
+)
+
+__all__ = [
+    "BaseResemblanceModel",
+    "PermutationImportanceResemblance",
+    "SHAPImportanceResemblance",
+]
