@@ -18,7 +18,12 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-from scipy import stats
+from probatus.utils import NotInstalledError
+
+try:
+    from scipy import stats
+except ModuleNotFoundError:
+    stats = NotInstalledError("scipy", "extras")
 
 from ..utils import assure_numpy_array
 from probatus.stat_tests.utils import verbose_p_vals
@@ -27,8 +32,10 @@ from probatus.stat_tests.utils import verbose_p_vals
 @verbose_p_vals
 def es(d1, d2, verbose=False):
     """
-    Calculates the Epps-Singleton test statistic on 2 distributions. Can be used on continuous or discrete
-    distributions. Any binning/bucketing of the distributions/samples should be done before passing them to this
+    Calculates the Epps-Singleton test statistic on 2 distributions.
+
+    Can be used on continuous or discrete distributions.
+    Any binning/bucketing of the distributions/samples should be done before passing them to this
     function.
 
     Whereas KS relies on the empirical distribution function, ES is based on the empirical characteristic function
@@ -53,9 +60,9 @@ def es(d1, d2, verbose=False):
         verbose (bool) : helpful interpretation msgs printed to stdout (default False).
 
     Returns:
-        (float, float): ES test stat and p-value of rejecting the null hypothesis (that the two distributions are identical)
+        (float, float): ES test stat and p-value of rejecting the null hypothesis
+                        (that the two distributions are identical)
     """
-
     d1 = assure_numpy_array(d1)
     d2 = assure_numpy_array(d2)
 
